DOXYGEN_INPUT="
                         ${path_tag}${coin_build_dir}/include/Inventor/C/basic.h
                         ${path_tag}${coin_src_dir}/docs/releases.dox
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoAudioRenderAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoBoxHighlightRenderAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoCallbackAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoGetBoundingBoxAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoGetMatrixAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoGetPrimitiveCountAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoGlobalSimplifyAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoGLRenderAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoHandleEventAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoLineHighlightRenderAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoPickAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoRayPickAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoReorganizeAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoSearchAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoShapeSimplifyAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoSimplifyAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoSubAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoToVRML2Action.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoToVRMLAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/actions/SoWriteAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/ForeignFiles/SoForeignFileKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/ForeignFiles/SoSTLFileKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/FXViz/elements/SoGLShadowCullingElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/FXViz/elements/SoShadowStyleElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/FXViz/nodes/SoShadowCulling.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/FXViz/nodes/SoShadowDirectionalLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/FXViz/nodes/SoShadowGroup.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/FXViz/nodes/SoShadowSpotLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/FXViz/nodes/SoShadowStyle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/HardCopy/SoHardCopy.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/HardCopy/SoPSVectorOutput.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/HardCopy/SoVectorizeAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/HardCopy/SoVectorizePSAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/HardCopy/SoVectorOutput.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/Profiler/elements/SoProfilerElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/Profiler/nodekits/SoNodeVisualize.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/Profiler/nodekits/SoProfilerOverlayKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/Profiler/nodes/SoProfilerStats.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/Profiler/SbProfilingData.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/Profiler/SoProfiler.h
                         ${path_tag}${coin_src_dir}/include/Inventor/annex/Profiler/utils/SoProfilingReportGenerator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/bundles/SoBundle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/bundles/SoMaterialBundle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/bundles/SoNormalBundle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/bundles/SoTextureCoordinateBundle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/bundles/SoVertexAttributeBundle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoBoundingBoxCache.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoCache.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoConvexDataCache.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoGLCacheList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoGLRenderCache.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoNormalCache.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoPrimitiveVertexCache.h
                         ${path_tag}${coin_src_dir}/include/Inventor/caches/SoTextureCoordinateCache.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/base/hash.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/base/heap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/base/memalloc.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/base/rbptree.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/base/string.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/base/time.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/errors/debugerror.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/errors/error.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/glue/dl.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/glue/spidermonkey.h
                         ${path_tag}${coin_src_dir}/include/Inventor/collision/SoIntersectionDetectionAction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/barrier.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/common.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/condvar.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/fifo.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/mutex.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/recmutex.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/rwmutex.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/sched.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/storage.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/sync.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/thread.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/worker.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/threads/wpool.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/tidbits.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/XML/attribute.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/XML/document.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/XML/element.h
                         ${path_tag}${coin_src_dir}/include/Inventor/C/XML/types.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoConeDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoCubeDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoCylinderDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoFaceDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoLineDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoNodeKitDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoPointDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/details/SoTextDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoCenterballDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoDirectionalLightDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoDragPointDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoHandleBoxDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoJackDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoPointLightDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoRotateCylindricalDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoRotateDiscDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoRotateSphericalDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoScale1Dragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoScale2Dragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoScale2UniformDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoScaleUniformDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoSpotLightDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoTabBoxDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoTabPlaneDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoTrackballDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoTransformBoxDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoTransformerDragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoTranslate1Dragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/draggers/SoTranslate2Dragger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoAccumulatedElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoAmbientColorElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoAnnoText3CharOrientElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoAnnoText3FontSizeHintElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoAnnoText3RenderPrintElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoBBoxModelMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoBumpMapCoordinateElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoBumpMapElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoBumpMapMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoCacheElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoCacheHintElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoClipPlaneElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoComplexityElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoComplexityTypeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoCoordinateElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoCreaseAngleElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoCullElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoDecimationPercentageElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoDecimationTypeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoDepthBufferElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoDiffuseColorElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoDrawStyleElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoEmissiveColorElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoEnvironmentElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoFloatElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoFocalDistanceElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoFontNameElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoFontSizeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGeoElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLCacheContextElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLClipPlaneElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLColorIndexElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLCoordinateElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLDepthBufferElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLDisplayList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLDrawStyleElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLEnvironmentElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLLazyElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLLightIdElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLLinePatternElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLLineWidthElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLModelMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLMultiTextureCoordinateElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLMultiTextureEnabledElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLMultiTextureImageElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLMultiTextureMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLNormalElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLPointSizeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLPolygonOffsetElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLProjectionMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLRenderPassElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLShapeHintsElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLTextureEnabledElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLUpdateAreaElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLVBOElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLVertexAttributeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLViewingMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoGLViewportRegionElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoInt32Element.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoLazyElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoLightAttenuationElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoLightElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoLightModelElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoLinePatternElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoLineWidthElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoListenerDopplerElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoListenerGainElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoListenerOrientationElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoListenerPositionElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoLocalBBoxMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoMaterialBindingElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoModelMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoMultiTextureCoordinateElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoMultiTextureEnabledElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoMultiTextureImageElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoMultiTextureMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoNormalBindingElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoNormalElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoOverrideElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoPickRayElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoPickStyleElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoPointSizeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoPolygonOffsetElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoProfileCoordinateElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoProfileElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoProjectionMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoReplacedElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoShapeHintsElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoShapeStyleElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoShininessElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoSoundElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoSpecularColorElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoSubElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoSwitchElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoTextOutlineEnabledElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoTextureCombineElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoTextureCoordinateBindingElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoTextureOverrideElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoTextureQualityElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoTextureUnitElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoTransparencyElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoUnitsElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoVertexAttributeBindingElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoVertexAttributeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoViewingMatrixElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoViewportRegionElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoViewVolumeElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/elements/SoWindowElement.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoBoolOperation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoCalculator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoComposeMatrix.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoComposeRotationFromTo.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoComposeRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoComposeVec2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoComposeVec3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoComposeVec4f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoComputeBoundingBox.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoConcatenate.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoCounter.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoDecomposeMatrix.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoDecomposeRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoDecomposeVec2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoDecomposeVec3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoDecomposeVec4f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoElapsedTime.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoEngine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoEngineOutput.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoFieldConverter.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoGate.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoHeightMapToNormalMap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoInterpolateFloat.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoInterpolate.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoInterpolateRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoInterpolateVec2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoInterpolateVec3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoInterpolateVec4f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoNodeEngine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoOneShot.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoOnOff.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoOutputData.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoSelectOne.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoTexture2Convert.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoTimeCounter.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoTransformVec3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/engines/SoTriggerAny.h
                         ${path_tag}${coin_src_dir}/include/Inventor/errors/SoDebugError.h
                         ${path_tag}${coin_src_dir}/include/Inventor/errors/SoError.h
                         ${path_tag}${coin_src_dir}/include/Inventor/errors/SoMemoryError.h
                         ${path_tag}${coin_src_dir}/include/Inventor/errors/SoReadError.h
                         ${path_tag}${coin_src_dir}/include/Inventor/events/SoButtonEvent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/events/SoEvent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/events/SoKeyboardEvent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/events/SoLocation2Event.h
                         ${path_tag}${coin_src_dir}/include/Inventor/events/SoMotion3Event.h
                         ${path_tag}${coin_src_dir}/include/Inventor/events/SoMouseButtonEvent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/events/SoSpaceballButtonEvent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoFieldContainer.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoFieldData.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoField.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFBitMask.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFBool.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFColor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFColorRGBA.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFDouble.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFEngine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFEnum.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFFloat.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMField.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFInt32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFMatrix.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFName.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFNode.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFPath.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFPlane.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFShort.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFString.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFTime.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFUInt32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFUShort.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec2b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec2d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec2i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec2s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec3b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec3d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec3i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec3s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4ub.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4ui32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoMFVec4us.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBitMask.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBool.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox2d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox2i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox2s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox3d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox3i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFBox3s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFColor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFColorRGBA.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFDouble.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFEngine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFEnum.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFFloat.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSField.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFImage3.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFImage.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFInt32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFMatrix.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFName.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFNode.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFPath.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFPlane.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFShort.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFString.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFTime.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFTrigger.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFUInt32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFUShort.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec2b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec2d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec2i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec2s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec3b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec3d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec3i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec3s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4ub.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4ui32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSFVec4us.h
                         ${path_tag}${coin_src_dir}/include/Inventor/fields/SoSubField.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SbIntList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SbList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SbPList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SbStringList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SbVec3fList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoActionMethodList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoAuditorList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoBaseList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoCallbackList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoDetailList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoEnabledElementsList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoEngineList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoEngineOutputList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoFieldList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoNodeList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoPathList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoPickedPointList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lists/SoTypeList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/lock/SoLockMgr.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoCenterballManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoClipPlaneManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoDirectionalLightManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoHandleBoxManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoJackManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoPointLightManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoSpotLightManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoTabBoxManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoTrackballManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoTransformBoxManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoTransformerManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/manips/SoTransformManip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/CoinResources.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoAudioDevice.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoBase.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoChildList.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoContextHandler.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoGLBigImage.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoGLCubeMapImage.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoGLDriverDatabase.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoGLImage.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoGlyph.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoJavaScriptEngine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoLightPath.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoNormalGenerator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoNotification.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoNotRec.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoProto.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoProtoInstance.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoState.h
                         ${path_tag}${coin_src_dir}/include/Inventor/misc/SoTempPath.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLDollyTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLFlightControlTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLMiscTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLMotionTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLNavigation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLNavigationTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLPanTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLRotateTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLSeekTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLSpinTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/navigation/SoScXMLZoomTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoAppearanceKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoBaseKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoCameraKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoInteractionKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoLightKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoNodekitCatalog.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoNodeKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoNodeKitListPart.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoSceneKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoSeparatorKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoShapeKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodekits/SoWrapperKit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoAlphaTest.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoAnnotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoAntiSquish.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoArray.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoAsciiText.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoBaseColor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoBlinker.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoBumpMapCoordinate.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoBumpMap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoBumpMapTransform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCacheHint.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCallback.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCamera.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoClipPlane.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoColorIndex.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoComplexity.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCone.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCoordinate3.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCoordinate4.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCube.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoCylinder.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoDepthBuffer.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoDirectionalLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoDrawStyle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoEnvironment.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoEventCallback.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoExtSelection.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoFaceSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoFile.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoFont.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoFontStyle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoFragmentShader.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoFrustumCamera.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoGeoCoordinate.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoGeoLocation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoGeometryShader.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoGeoOrigin.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoGeoSeparator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoGroup.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoImage.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedFaceSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedLineSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedMarkerSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedNurbsCurve.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedNurbsSurface.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedPointSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedShape.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoIndexedTriangleStripSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoInfo.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLabel.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLevelOfDetail.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLightModel.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLinearProfile.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLineSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoListener.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLocateHighlight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoLOD.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoMarkerSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoMaterialBinding.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoMaterial.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoMatrixTransform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoMultipleCopy.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoNode.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoNonIndexedShape.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoNormalBinding.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoNormal.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoNurbsCurve.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoNurbsProfile.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoNurbsSurface.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoOrthographicCamera.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPackedColor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPathSwitch.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPendulum.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPerspectiveCamera.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPickStyle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPointLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPointSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPolygonOffset.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoProfileCoordinate2.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoProfileCoordinate3.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoProfile.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoQuadMesh.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoResetTransform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoPerspectiveCamera.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoRotationXYZ.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoRotor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoScale.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSceneTexture2.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSceneTextureCubeMap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSelection.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSeparator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoShaderObject.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoShaderParameter.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoShaderProgram.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoShape.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoShapeHints.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoShuttle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSphere.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSpotLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSubNode.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSurroundScale.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoSwitch.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoText2.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoText3.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTexture2.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTexture2Transform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTexture3.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTexture3Transform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCombine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinate2.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinate3.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateBinding.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateCube.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateCylinder.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateDefault.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateEnvironment.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateFunction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateNormalMap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateObject.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinatePlane.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateReflectionMap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCoordinateSphere.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureCubeMap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTexture.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureMatrixTransform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureScalePolicy.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTextureUnit.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTransformation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTransform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTransformSeparator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTranslation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTransparencyType.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoTriangleStripSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoUnits.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoVertexAttributeBinding.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoVertexAttribute.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoVertexProperty.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoVertexShader.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoVertexShape.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoWWWAnchor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/nodes/SoWWWInline.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbCylinderPlaneProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbCylinderProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbCylinderSectionProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbCylinderSheetProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbLineProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbPlaneProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbSpherePlaneProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbSphereProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbSphereSectionProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/projectors/SbSphereSheetProjector.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBasic.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox2d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox2i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox2s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox3d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox3i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBox3s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbBSPTree.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbClip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbColor4f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbColor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbCylinder.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbDict.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbDPLine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbDPMatrix.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbDPPlane.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbDPRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbDPViewVolume.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbHeap.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbImage.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbLine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbMatrix.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbName.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbOctTree.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbPlane.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbRotation.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbSphere.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbString.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbTesselator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbTime.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbTypeInfo.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2ub.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2ui32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec2us.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3ub.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3ui32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec3us.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec4b.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec4d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec4f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec4i32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec4s.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec4ub.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbVec4ui32.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbViewportRegion.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbViewVolume.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbXfBox3d.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SbXfBox3f.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLAbstractStateElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLAnchorElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLAssignElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLCoinEvaluator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLContentElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLDataElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLDataModelElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLDocument.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLECMAScriptEvaluator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLElseElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLElseIfElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLEvaluator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLEventElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLEvent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLEventTarget.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLExecutableElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLFinalElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLFinalizeElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXML.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLHistoryElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLIfElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLInitialElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLInvokeElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLLogElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLMinimumEvaluator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLObject.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLOnEntryElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLOnExitElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLParallelElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLParamElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLScriptElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLScxmlElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLSendElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLStateElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLStateMachine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLTransitionElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLValidateElt.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/ScXMLXPathEvaluator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/SoScXMLEvent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/scxml/SoScXMLStateMachine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoAlarmSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoDataSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoDelayQueueSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoFieldSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoIdleSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoNodeSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoOneShotSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoPathSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoSensorManager.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoTimerQueueSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/sensors/SoTimerSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoDB.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoEventManager.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoFullPath.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoInput.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoInteraction.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoNodeKitPath.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoOffscreenRenderer.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoOutput.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoPath.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoPickedPoint.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoPrimitiveVertex.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoRenderManager.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoSceneManager.h
                         ${path_tag}${coin_src_dir}/include/Inventor/SoType.h
                         ${path_tag}${coin_src_dir}/include/Inventor/system/gl.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLAnchor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLAppearance.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLAudioClip.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLBackground.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLBillboard.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLBox.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLCollision.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLColor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLColorInterpolator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLCone.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLCoordinate.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLCoordinateInterpolator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLCylinder.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLCylinderSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLDirectionalLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLDragSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLElevationGrid.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLExtrusion.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLFog.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLFontStyle.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLGeometry.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLGroup.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLImageTexture.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLIndexedFaceSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLIndexedLine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLIndexedLineSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLIndexedShape.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLInline.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLInterpolator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLLOD.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLMaterial.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLMovieTexture.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLNavigationInfo.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLNormal.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLNormalInterpolator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLOrientationInterpolator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLParent.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLPixelTexture.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLPlaneSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLPointLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLPointSet.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLPositionInterpolator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLProximitySensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLScalarInterpolator.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLScript.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLShape.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLSound.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLSphere.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLSphereSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLSpotLight.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLSwitch.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLText.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLTextureCoordinate.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLTexture.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLTextureTransform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLTimeSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLTouchSensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLTransform.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLVertexLine.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLVertexPoint.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLVertexShape.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLViewpoint.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLVisibilitySensor.h
                         ${path_tag}${coin_src_dir}/include/Inventor/VRMLnodes/SoVRMLWorldInfo.h
                         ${path_tag}${coin_src_dir}/include/SoDebug.h
                         ${path_tag}${coin_src_dir}/src/actions/SoAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoActionP.h
                         ${path_tag}${coin_src_dir}/src/actions/SoAudioRenderAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoBoxHighlightRenderAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoCallbackAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoGetBoundingBoxAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoGetMatrixAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoGetPrimitiveCountAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoGlobalSimplifyAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoGLRenderAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoHandleEventAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoLineHighlightRenderAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoPickAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoRayPickAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoReorganizeAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoSearchAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoShapeSimplifyAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoSimplifyAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoToVRML2Action.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoToVRMLAction.cpp
                         ${path_tag}${coin_src_dir}/src/actions/SoWriteAction.cpp
                         ${path_tag}${coin_src_dir}/src/base/dict.cpp
                         ${path_tag}${coin_src_dir}/src/base/hash.cpp
                         ${path_tag}${coin_src_dir}/src/base/heap.cpp
                         ${path_tag}${coin_src_dir}/src/base/memalloc.cpp
                         ${path_tag}${coin_src_dir}/src/base/namemap.cpp
                         ${path_tag}${coin_src_dir}/src/base/rbptree.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox2d.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox2f.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox2i32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox2s.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox3d.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox3f.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox3i32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBox3s.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbBSPTree.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbClip.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbColor4f.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbColor.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbCylinder.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbDict.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbDPLine.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbDPMatrix.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbDPPlane.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbDPRotation.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbDPViewVolume.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbHeap.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbImage.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbLine.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbMatrix.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbName.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbOctTree.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbPlane.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbRotation.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbSphere.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbString.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbTesselator.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbTime.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2b.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2d.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2f.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2i32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2s.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2ub.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2ui32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec2us.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3b.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3d.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3f.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3i32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3s.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3ub.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3ui32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec3us.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec4b.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec4d.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec4f.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec4i32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec4s.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec4ub.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbVec4ui32.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbViewportRegion.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbViewVolume.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbXfBox3d.cpp
                         ${path_tag}${coin_src_dir}/src/base/SbXfBox3f.cpp
                         ${path_tag}${coin_src_dir}/src/base/string.cpp
                         ${path_tag}${coin_src_dir}/src/base/time.cpp
                         ${path_tag}${coin_src_dir}/src/bundles/SoBundle.cpp
                         ${path_tag}${coin_src_dir}/src/bundles/SoMaterialBundle.cpp
                         ${path_tag}${coin_src_dir}/src/bundles/SoNormalBundle.cpp
                         ${path_tag}${coin_src_dir}/src/bundles/SoTextureCoordinateBundle.cpp
                         ${path_tag}${coin_src_dir}/src/bundles/SoVertexAttributeBundle.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoBoundingBoxCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoConvexDataCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoGLCacheList.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoGLRenderCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoGlyphCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoGlyphCache.h
                         ${path_tag}${coin_src_dir}/src/caches/SoNormalCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoPrimitiveVertexCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoShaderProgramCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoShaderProgramCache.h
                         ${path_tag}${coin_src_dir}/src/caches/SoTextureCoordinateCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoVBOCache.cpp
                         ${path_tag}${coin_src_dir}/src/caches/SoVBOCache.h
                         ${path_tag}${coin_src_dir}/src/collision/SbTri3f.cpp
                         ${path_tag}${coin_src_dir}/src/collision/SbTri3f.h
                         ${path_tag}${coin_src_dir}/src/collision/SoIntersectionDetectionAction.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoConeDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoCubeDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoCylinderDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoFaceDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoLineDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoNodeKitDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoPointDetail.cpp
                         ${path_tag}${coin_src_dir}/src/details/SoTextDetail.cpp
                         ${path_tag}${coin_src_dir}/src/doc/Coin_books.dox
                         ${path_tag}${coin_src_dir}/src/doc/Coin_environment.dox
                         ${path_tag}${coin_src_dir}/src/doc/environment.dox.h
                         ${path_tag}${coin_src_dir}/src/doc/Coin_macros.dox
                         ${path_tag}${coin_src_dir}/src/doc/Coin_main.dox
                         ${path_tag}${coin_src_dir}/src/doc/Coin_modules.dox
                         ${path_tag}${coin_src_dir}/src/draggers/SoCenterballDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoDirectionalLightDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoDragPointDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoHandleBoxDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoJackDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoPointLightDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoRotateCylindricalDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoRotateDiscDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoRotateSphericalDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoScale1Dragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoScale2Dragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoScale2UniformDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoScaleUniformDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoSpotLightDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoTabBoxDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoTabPlaneDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoTrackballDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoTransformBoxDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoTransformerDragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoTranslate1Dragger.cpp
                         ${path_tag}${coin_src_dir}/src/draggers/SoTranslate2Dragger.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLCacheContextElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLClipPlaneElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLColorIndexElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLCoordinateElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLDepthBufferElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLDisplayList.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLDrawStyleElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLEnvironmentElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLLazyElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLLightIdElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLLinePatternElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLLineWidthElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLModelMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLMultiTextureCoordinateElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLMultiTextureEnabledElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLMultiTextureImageElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLMultiTextureMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLNormalElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLPointSizeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLPolygonOffsetElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLProjectionMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLRenderPassElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLShapeHintsElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLUpdateAreaElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLVBOElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLVertexAttributeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLViewingMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoGLViewportRegionElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoResetMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/GL/SoResetMatrixElement.h
                         ${path_tag}${coin_src_dir}/src/elements/SoAccumulatedElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoAmbientColorElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoAnnoText3CharOrientElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoAnnoText3FontSizeHintElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoAnnoText3RenderPrintElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoBBoxModelMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoBumpMapCoordinateElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoBumpMapElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoBumpMapMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoCacheElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoCacheHintElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoClipPlaneElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoComplexityElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoComplexityTypeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoCoordinateElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoCreaseAngleElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoCullElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoDecimationPercentageElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoDecimationTypeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoDepthBufferElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoDiffuseColorElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoDrawStyleElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoEmissiveColorElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoEnvironmentElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoFloatElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoFocalDistanceElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoFontNameElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoFontSizeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoInt32Element.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoLazyElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoLightAttenuationElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoLightElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoLightModelElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoLinePatternElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoLineWidthElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoListenerDopplerElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoListenerGainElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoListenerOrientationElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoListenerPositionElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoLocalBBoxMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoMaterialBindingElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoModelMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoMultiTextureCoordinateElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoMultiTextureEnabledElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoMultiTextureImageElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoMultiTextureMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoNormalBindingElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoNormalElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoOverrideElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoPickRayElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoPickStyleElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoPointSizeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoPolygonOffsetElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoProfileCoordinateElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoProfileElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoProjectionMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoReplacedElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoShapeHintsElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoShapeStyleElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoShininessElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoSoundElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoSpecularColorElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoSwitchElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextOutlineEnabledElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureCombineElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureCoordinateBindingElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureOverrideElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureQualityElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureScalePolicyElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureScalePolicyElement.h
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureScaleQualityElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureScaleQualityElement.h
                         ${path_tag}${coin_src_dir}/src/elements/SoTextureUnitElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoTransparencyElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoUnitsElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoVertexAttributeBindingElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoVertexAttributeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoViewingMatrixElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoViewportRegionElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoViewVolumeElement.cpp
                         ${path_tag}${coin_src_dir}/src/elements/SoWindowElement.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoBoolOperation.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoCalculator.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoComposeMatrix.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoComposeRotation.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoComposeRotationFromTo.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoComposeVec2f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoComposeVec3f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoComposeVec4f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoComputeBoundingBox.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoConcatenate.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoCounter.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoDecomposeMatrix.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoDecomposeRotation.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoDecomposeVec2f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoDecomposeVec3f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoDecomposeVec4f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoElapsedTime.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoEngine.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoEngineOutput.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoFieldConverter.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoGate.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoHeightMapToNormalMap.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoInterpolate.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoInterpolateFloat.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoInterpolateRotation.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoInterpolateVec2f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoInterpolateVec3f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoInterpolateVec4f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoNodeEngine.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoOneShot.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoOnOff.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoOutputData.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoSelectOne.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoTexture2Convert.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoTimeCounter.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoTransformVec3f.cpp
                         ${path_tag}${coin_src_dir}/src/engines/SoTriggerAny.cpp
                         ${path_tag}${coin_src_dir}/src/errors/debugerror.cpp
                         ${path_tag}${coin_src_dir}/src/errors/error.cpp
                         ${path_tag}${coin_src_dir}/src/errors/SoDebugError.cpp
                         ${path_tag}${coin_src_dir}/src/errors/SoError.cpp
                         ${path_tag}${coin_src_dir}/src/errors/SoMemoryError.cpp
                         ${path_tag}${coin_src_dir}/src/errors/SoReadError.cpp
                         ${path_tag}${coin_src_dir}/src/events/SoButtonEvent.cpp
                         ${path_tag}${coin_src_dir}/src/events/SoEvent.cpp
                         ${path_tag}${coin_src_dir}/src/events/SoKeyboardEvent.cpp
                         ${path_tag}${coin_src_dir}/src/events/SoLocation2Event.cpp
                         ${path_tag}${coin_src_dir}/src/events/SoMotion3Event.cpp
                         ${path_tag}${coin_src_dir}/src/events/SoMouseButtonEvent.cpp
                         ${path_tag}${coin_src_dir}/src/events/SoSpaceballButtonEvent.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoFieldContainer.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoField.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoFieldData.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFBitMask.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFBool.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFColor.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFColorRGBA.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFDouble.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFEngine.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFEnum.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFFloat.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMField.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFInt32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFMatrix.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFName.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFNode.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFPath.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFPlane.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFRotation.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFShort.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFString.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFTime.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFUInt32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFUShort.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec2b.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec2d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec2f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec2i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec2s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec3b.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec3d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec3f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec3i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec3s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4b.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4ub.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4ui32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoMFVec4us.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBitMask.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBool.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox2d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox2f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox2i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox2s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox3d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox3f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox3i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFBox3s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFColor.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFColorRGBA.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFDouble.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFEngine.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFEnum.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFFloat.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSField.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFImage3.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFImage.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFInt32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFMatrix.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFName.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFNode.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFPath.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFPlane.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFRotation.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFShort.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFString.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFTime.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFTrigger.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFUInt32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFUShort.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec2b.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec2d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec2f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec2i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec2s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec3b.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec3d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec3f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec3i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec3s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4b.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4d.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4f.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4i32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4s.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4ub.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4ui32.cpp
                         ${path_tag}${coin_src_dir}/src/fields/SoSFVec4us.cpp
                         ${path_tag}${coin_src_dir}/src/fonts/fontlib_wrapper.cpp
                         ${path_tag}${coin_src_dir}/src/foreignfiles/SoForeignFileKit.cpp
                         ${path_tag}${coin_src_dir}/src/foreignfiles/SoSTLFileKit.cpp
                         ${path_tag}${coin_src_dir}/src/geo/SoGeoCoordinate.cpp
                         ${path_tag}${coin_src_dir}/src/geo/SoGeoElement.cpp
                         ${path_tag}${coin_src_dir}/src/geo/SoGeoLocation.cpp
                         ${path_tag}${coin_src_dir}/src/geo/SoGeoOrigin.cpp
                         ${path_tag}${coin_src_dir}/src/geo/SoGeoSeparator.cpp
                         ${path_tag}${coin_src_dir}/src/glue/dl.cpp
                         ${path_tag}${coin_src_dir}/src/glue/gl.cpp
                         ${path_tag}${coin_src_dir}/src/glue/spidermonkey.cpp
                         ${path_tag}${coin_src_dir}/src/hardcopy/HardCopy.cpp
                         ${path_tag}${coin_src_dir}/src/hardcopy/PSVectorOutput.cpp
                         ${path_tag}${coin_src_dir}/src/hardcopy/VectorizeAction.cpp
                         ${path_tag}${coin_src_dir}/src/hardcopy/VectorizePSAction.cpp
                         ${path_tag}${coin_src_dir}/src/hardcopy/VectorOutput.cpp
                         ${path_tag}${coin_src_dir}/src/io/SoInput.cpp
                         ${path_tag}${coin_src_dir}/src/io/SoInputP.h
                         ${path_tag}${coin_src_dir}/src/io/SoOutput.cpp
                         ${path_tag}${coin_src_dir}/src/io/SoWriterefCounter.cpp
                         ${path_tag}${coin_src_dir}/src/io/SoWriterefCounter.h
                         ${path_tag}${coin_src_dir}/src/lists/SbIntList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SbList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SbPList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SbStringList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SbVec3fList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoActionMethodList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoAuditorList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoBaseList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoCallbackList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoDetailList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoEnabledElementsList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoEngineList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoEngineOutputList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoFieldList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoNodeList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoPathList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoPickedPointList.cpp
                         ${path_tag}${coin_src_dir}/src/lists/SoTypeList.cpp
                         ${path_tag}${coin_src_dir}/src/manips/commoncode.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoCenterballManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoClipPlaneManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoDirectionalLightManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoHandleBoxManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoJackManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoPointLightManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoSpotLightManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoTabBoxManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoTrackballManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoTransformBoxManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoTransformerManip.cpp
                         ${path_tag}${coin_src_dir}/src/manips/SoTransformManip.cpp
                         ${path_tag}${coin_src_dir}/src/misc/CoinResources.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoAudioDevice.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoBase.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoChildList.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoCompactPathList.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoCompactPathList.h
                         ${path_tag}${coin_src_dir}/src/misc/SoContextHandler.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoDB.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoDebug.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoEventManager.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoFullPath.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoGlyph.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoInteraction.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoJavaScriptEngine.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoLightPath.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoLockManager.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoNormalGenerator.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoNotification.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoNotRec.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoPath.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoPickedPoint.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoPrimitiveVertex.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoProto.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoProtoInstance.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoSceneManager.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoShaderGenerator.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoShaderGenerator.h
                         ${path_tag}${coin_src_dir}/src/misc/SoState.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoTempPath.cpp
                         ${path_tag}${coin_src_dir}/src/misc/SoType.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLDollyTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLFlightControlTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLMiscTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLMotionTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLNavigation.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLNavigationTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLPanTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLRotateTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLSeekTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLSpinTarget.cpp
                         ${path_tag}${coin_src_dir}/src/navigation/SoScXMLZoomTarget.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoAppearanceKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoBaseKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoCameraKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoInteractionKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoLightKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoNodekitCatalog.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoNodeKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoNodeKitListPart.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoNodeKitPath.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoSceneKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoSeparatorKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoShapeKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodekits/SoWrapperKit.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoAlphaTest.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoAnnotation.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoAntiSquish.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoArray.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoBaseColor.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoBlinker.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoBumpMapCoordinate.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoBumpMap.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoBumpMapTransform.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoCacheHint.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoCallback.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoCamera.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoClipPlane.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoColorIndex.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoComplexity.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoCoordinate3.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoCoordinate4.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoDepthBuffer.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoDirectionalLight.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoDrawStyle.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoEnvironment.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoEventCallback.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoExtSelection.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoFile.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoFont.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoFontStyle.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoFrustumCamera.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoGroup.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoInfo.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoLabel.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoLevelOfDetail.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoLight.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoLightModel.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoLinearProfile.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoListener.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoLocateHighlight.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoLOD.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoMaterialBinding.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoMaterial.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoMatrixTransform.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoMultipleCopy.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoNode.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoNormalBinding.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoNormal.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoNurbsProfile.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoOrthographicCamera.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoPackedColor.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoPathSwitch.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoPendulum.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoPerspectiveCamera.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoPickStyle.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoPointLight.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoPolygonOffset.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoProfileCoordinate2.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoProfileCoordinate3.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoProfile.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoResetTransform.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoReversePerspectiveCamera.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoRotation.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoRotationXYZ.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoRotor.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoScale.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoSceneTexture2.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoSceneTextureCubeMap.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoSelection.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoSeparator.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoShapeHints.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoShuttle.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoSpotLight.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoSurroundScale.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoSwitch.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTexture2.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTexture2Transform.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTexture3.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTexture3Transform.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCombine.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinate2.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinate3.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateBinding.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateCube.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateCylinder.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateDefault.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateEnvironment.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateFunction.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateNormalMap.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateObject.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinatePlane.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateReflectionMap.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCoordinateSphere.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTexture.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureCubeMap.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureMatrixTransform.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureScalePolicy.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTextureUnit.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTransformation.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTransform.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTransformSeparator.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTranslation.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoTransparencyType.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoUnits.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoVertexAttributeBinding.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoVertexAttribute.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoVertexProperty.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoWWWAnchor.cpp
                         ${path_tag}${coin_src_dir}/src/nodes/SoWWWInline.cpp
                         ${path_tag}${coin_src_dir}/src/profiler/SbProfilingData.cpp
                         ${path_tag}${coin_src_dir}/src/profiler/SoNodeVisualize.cpp
                         ${path_tag}${coin_src_dir}/src/profiler/SoProfiler.cpp
                         ${path_tag}${coin_src_dir}/src/profiler/SoProfilerElement.cpp
                         ${path_tag}${coin_src_dir}/src/profiler/SoProfilerOverlayKit.cpp
                         ${path_tag}${coin_src_dir}/src/profiler/SoProfilerP.h
                         ${path_tag}${coin_src_dir}/src/profiler/SoProfilerStats.cpp
                         ${path_tag}${coin_src_dir}/src/profiler/SoProfilingReportGenerator.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbCylinderPlaneProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbCylinderProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbCylinderSectionProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbCylinderSheetProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbLineProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbPlaneProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbSpherePlaneProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbSphereProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbSphereSectionProjector.cpp
                         ${path_tag}${coin_src_dir}/src/projectors/SbSphereSheetProjector.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoGLBigImage.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoGL.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoGLCubeMapImage.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoGLDriverDatabase.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoGLImage.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoOffscreenRenderer.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoRenderManager.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoVBO.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoVBO.h
                         ${path_tag}${coin_src_dir}/src/rendering/SoVertexArrayIndexer.cpp
                         ${path_tag}${coin_src_dir}/src/rendering/SoVertexArrayIndexer.h
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLAbstractStateElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLAnchorElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLAssignElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLContentElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXML.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLDataElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLDataModelElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLDocument.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLECMAScriptEvaluator.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLElseElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLElseIfElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLEvaluator.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLEvent.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLEventElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLEventTarget.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLExecutableElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLFinalElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLFinalizeElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLHistoryElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLIfElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLInitialElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLInvokeElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLLogElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLMinimumEvaluator.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLObject.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLOnEntryElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLOnExitElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLP.h
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLParallelElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLParamElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLScriptElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLScxmlElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLSendElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLStateElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLStateMachine.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLTransitionElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLValidateElt.cpp
                         ${path_tag}${coin_src_dir}/src/scxml/ScXMLXPathEvaluator.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoAlarmSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoDataSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoDelayQueueSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoFieldSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoIdleSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoNodeSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoOneShotSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoPathSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoSensorManager.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoTimerQueueSensor.cpp
                         ${path_tag}${coin_src_dir}/src/sensors/SoTimerSensor.cpp
                         ${path_tag}${coin_src_dir}/src/shaders/SoFragmentShader.cpp
                         ${path_tag}${coin_src_dir}/src/shaders/SoGeometryShader.cpp
                         ${path_tag}${coin_src_dir}/src/shaders/SoShader.cpp
                         ${path_tag}${coin_src_dir}/src/shaders/SoShader.h
                         ${path_tag}${coin_src_dir}/src/shaders/SoShaderObject.cpp
                         ${path_tag}${coin_src_dir}/src/shaders/SoShaderParameter.cpp
                         ${path_tag}${coin_src_dir}/src/shaders/SoShaderProgram.cpp
                         ${path_tag}${coin_src_dir}/src/shaders/SoVertexShader.cpp
                         ${path_tag}${coin_src_dir}/src/shadows/SoGLShadowCullingElement.cpp
                         ${path_tag}${coin_src_dir}/src/shadows/SoShadowCulling.cpp
                         ${path_tag}${coin_src_dir}/src/shadows/SoShadowDirectionalLight.cpp
                         ${path_tag}${coin_src_dir}/src/shadows/SoShadowGroup.cpp
                         ${path_tag}${coin_src_dir}/src/shadows/SoShadowSpotLight.cpp
                         ${path_tag}${coin_src_dir}/src/shadows/SoShadowStyle.cpp
                         ${path_tag}${coin_src_dir}/src/shadows/SoShadowStyleElement.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoAsciiText.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoCone.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoCube.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoCylinder.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoFaceSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoImage.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedFaceSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedLineSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedMarkerSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedNurbsCurve.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedNurbsSurface.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedPointSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedShape.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoIndexedTriangleStripSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoLineSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoMarkerSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoNonIndexedShape.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoNurbsCurve.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoNurbsSurface.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoPointSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoQuadMesh.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoShape.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoSphere.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoText2.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoText3.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoTriangleStripSet.cpp
                         ${path_tag}${coin_src_dir}/src/shapenodes/SoVertexShape.cpp
                         ${path_tag}${coin_src_dir}/src/soscxml/ScXMLCoinEvaluator.cpp
                         ${path_tag}${coin_src_dir}/src/soscxml/SoScXMLEvent.cpp
                         ${path_tag}${coin_src_dir}/src/soscxml/SoScXMLStateMachine.cpp
                         ${path_tag}${coin_src_dir}/src/threads/barrier.cpp
                         ${path_tag}${coin_src_dir}/src/threads/barrierp.h
                         ${path_tag}${coin_src_dir}/src/threads/common.cpp
                         ${path_tag}${coin_src_dir}/src/threads/condvar.cpp
                         ${path_tag}${coin_src_dir}/src/threads/condvarp.h
                         ${path_tag}${coin_src_dir}/src/threads/fifo.cpp
                         ${path_tag}${coin_src_dir}/src/threads/fifop.h
                         ${path_tag}${coin_src_dir}/src/threads/mutex.cpp
                         ${path_tag}${coin_src_dir}/src/threads/mutexp.h
                         ${path_tag}${coin_src_dir}/src/threads/recmutex.cpp
                         ${path_tag}${coin_src_dir}/src/threads/recmutexp.h
                         ${path_tag}${coin_src_dir}/src/threads/rwmutex.cpp
                         ${path_tag}${coin_src_dir}/src/threads/rwmutexp.h
                         ${path_tag}${coin_src_dir}/src/threads/sched.cpp
                         ${path_tag}${coin_src_dir}/src/threads/schedp.h
                         ${path_tag}${coin_src_dir}/src/threads/storage.cpp
                         ${path_tag}${coin_src_dir}/src/threads/storagep.h
                         ${path_tag}${coin_src_dir}/src/threads/sync.cpp
                         ${path_tag}${coin_src_dir}/src/threads/thread.cpp
                         ${path_tag}${coin_src_dir}/src/threads/threadp.h
                         ${path_tag}${coin_src_dir}/src/threads/worker.cpp
                         ${path_tag}${coin_src_dir}/src/threads/workerp.h
                         ${path_tag}${coin_src_dir}/src/threads/wpool.cpp
                         ${path_tag}${coin_src_dir}/src/threads/wpoolp.h
                         ${path_tag}${coin_src_dir}/src/tidbits.cpp
                         ${path_tag}${coin_src_dir}/src/upgraders/SoPackedColorV20.cpp
                         ${path_tag}${coin_src_dir}/src/upgraders/SoPackedColorV20.h
                         ${path_tag}${coin_src_dir}/src/upgraders/SoShapeHintsV10.cpp
                         ${path_tag}${coin_src_dir}/src/upgraders/SoShapeHintsV10.h
                         ${path_tag}${coin_src_dir}/src/upgraders/SoUpgrader.cpp
                         ${path_tag}${coin_src_dir}/src/upgraders/SoUpgrader.h
                         ${path_tag}${coin_src_dir}/src/vrml97/Anchor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Appearance.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/AudioClip.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Background.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Billboard.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Box.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Collision.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Color.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/ColorInterpolator.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Cone.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Coordinate.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/CoordinateInterpolator.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Cylinder.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/CylinderSensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/DirectionalLight.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/DragSensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/ElevationGrid.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Extrusion.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Fog.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/FontStyle.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Geometry.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Group.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/ImageTexture.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/IndexedFaceSet.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/IndexedLine.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/IndexedLineSet.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/IndexedShape.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Inline.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Interpolator.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Light.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/LOD.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Material.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/MovieTexture.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/NavigationInfo.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Normal.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/NormalInterpolator.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/OrientationInterpolator.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Parent.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/PixelTexture.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/PlaneSensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/PointLight.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/PointSet.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/PositionInterpolator.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/ProximitySensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/ScalarInterpolator.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Script.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Sensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Shape.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Sound.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Sphere.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/SphereSensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/SpotLight.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Switch.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Text.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/TextureCoordinate.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Texture.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/TextureTransform.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/TimeSensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/TouchSensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Transform.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/VertexLine.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/VertexPoint.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/VertexShape.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/Viewpoint.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/VisibilitySensor.cpp
                         ${path_tag}${coin_src_dir}/src/vrml97/WorldInfo.cpp
                         ${path_tag}${coin_src_dir}/src/xml/attribute.cpp
                         ${path_tag}${coin_src_dir}/src/xml/document.cpp
                         ${path_tag}${coin_src_dir}/src/xml/element.cpp
                         ${path_tag}${coin_src_dir}/src/xml/types.cpp
"
